#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElementRRuleWeekDay :
	def __init__( self):
		self.day = None
		self.offset = None
		pass

class __ICalendarElementRRuleWeekDaySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ICalendarElementRRuleWeekDay()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		dayValue = value['day']
		instance.day = serder.STRING.parse(dayValue)
		offsetValue = value['offset']
		instance.offset = serder.INT.parse(offsetValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		dayValue = value.day
		instance["day"] = serder.STRING.encode(dayValue)
		offsetValue = value.offset
		instance["offset"] = serder.INT.encode(offsetValue)
		return instance

